function [] = CURexp_run(experiment,accelerate,plotResults,maxIter,maxPlotIter,initProxGap,lambda_row,lambda_col,initialL,thetaUpdate)

%% Properties of Experiment
data = {
	'9_Tumors.mat',
	'Brain_Tumor1.mat',
	'Leukemia1.mat',
	'SRBCT.mat'
	};

doFixedK = 0;
doFixedE = 0;
doGeom = 0;
doPoly = 0;
switch experiment
	case 'fixedK'
		doFixedK = 1;
	case 'fixedE'
		doFixedE = 1;
	case 'doPoly'
		doPoly = 1;
end

%% Properties of Individuals Methods

methods = cell(0,9);

switch experiment
	case 'fixedK'
		% Use fixed number of iterations
		methods(end+1,:) = {1,0,'fixed','',accelerate,thetaUpdate,'n=1',[.5 .5 1],'-'};
		methods(end+1,:) = {2,0,'fixed','',accelerate,thetaUpdate,'n=2',[.5 .5 1]*.8,'--'};
		methods(end+1,:) = {3,0,'fixed','',accelerate,thetaUpdate,'n=3',[.5 .5 1]*.6,'-.'};
		%methods(end+1,:) = {4,0,'fixed','',accelerate,thetaUpdate,'k=4',[0 0 1]*.4};
		methods(end+1,:) = {5,0,'fixed','',accelerate,thetaUpdate,'n=5',[.5 .5 1]*.2,':'};
		%methods(end+1,:) = {10,0,'fixed','',accelerate,thetaUpdate,'k=10',[0 0 1]*.2};
		%methods(end+1,:) = {15,0,'fixed','',accelerate,thetaUpdate,'k=15',[0 0 1]*.2,'-'};
	case 'fixedE'
		% Solve up to fixed accuracy
		methods(end+1,:) = {maxIter,1e-2,'fixed','',accelerate,thetaUpdate,'\epsilon_k=1e-2',[0 1 0],'-'};
		%methods(end+1,:) = {maxIter,1e-3,'fixed','',accelerate,thetaUpdate,'e=1e-3',[0 1 0]*.8,'-'};
		methods(end+1,:) = {maxIter,1e-4,'fixed','',accelerate,thetaUpdate,'\epsilon_k=1e-4',[0 1 0]*.8,'--'};
		%methods(end+1,:) = {maxIter,1e-5,'fixed','',accelerate,thetaUpdate,'e=1e-5',[0 1 0]*.4,'-'};
		methods(end+1,:) = {maxIter,1e-6,'fixed','',accelerate,thetaUpdate,'\epsilon_k=1e-6',[0 1 0]*.6,'-.'};
		methods(end+1,:) = {maxIter,1e-10,'fixed','',accelerate,thetaUpdate,'\epsilon_k=1e-10',[0 1 0]*.2,':'};
		%methods(end+1,:) = {maxIter,1e-15,'fixed','',accelerate,thetaUpdate,'e=1e-15',[0 1 0]*.2,'-'};
end

switch experiment
	case 'doPoly'
		% Solve with sub-linearly decreasing accuracy
		if accelerate
			methods(end+1,:) = {maxIter,initProxGap,'poly',1,accelerate,thetaUpdate,'\epsilon_k = 1/k',[1 .5 .5],'-'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',2,accelerate,thetaUpdate,'\epsilon_k = 1/k^2',[1 0 0]*.8,'--'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',3,accelerate,thetaUpdate,'\epsilon_k = 1/k^3',[1 0 0]*.4,'-.'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',4,accelerate,thetaUpdate,'\epsilon_k = 1/k^4',[1 0 0],'-'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',5,accelerate,thetaUpdate,'\epsilon_k = 1/k^5',[1 0 0]*.2,':'};
		else
			methods(end+1,:) = {maxIter,initProxGap,'poly',1,accelerate,thetaUpdate,'\epsilon_k = 1/k',[1 .5 .5],'-'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',2,accelerate,thetaUpdate,'\epsilon_k = 1/k^2',[1 0 0]*.8,'--'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',3,accelerate,thetaUpdate,'\epsilon_k = 1/k^3',[1 0 0],'-'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',4,accelerate,thetaUpdate,'\epsilon_k = 1/k^4',[1 0 0]*.4,'-.'};
			methods(end+1,:) = {maxIter,initProxGap,'poly',5,accelerate,thetaUpdate,'\epsilon_k = 1/k^5',[1 0 0]*.2,':'};
		end
	otherwise
		if accelerate
			methods(end+1,:) = {maxIter,initProxGap,'poly',4,accelerate,thetaUpdate,'\epsilon_k = 1/k^4',[1 0 0],'-'};
		else
			methods(end+1,:) = {maxIter,initProxGap,'poly',3,accelerate,thetaUpdate,'\epsilon_k = 1/k^3',[1 0 0],'-'};
		end
end
nMethods = size(methods,1);

for d = 1:length(data)
	dataset = data{d};
	xdata = cell(nMethods,1);
	ydata = cell(nMethods,1);
	legendStr = cell(nMethods,1);
	n = 1;
	minY = inf;
	for m = 1:nMethods
		maxProxIter = methods{m,1};
		proxGap = methods{m,2};
		gapSchedule = methods{m,3};
		gapParam = methods{m,4};
		accelerate = methods{m,5};
		thetaUpdate = methods{m,6};
		method = methods{m,7};
		fprintf('Accelerate = %d, method = %s, lambda_row = %f, lambda_col = %f, initProxGap = %f, initialL = %f, thetaUpdate = %d\n',accelerate,method,lambda_row,lambda_col,initProxGap,initialL,thetaUpdate);
		[info] = CURexp(dataset,maxIter,lambda_row,lambda_col,accelerate,maxProxIter,proxGap,gapSchedule,gapParam,initialL,thetaUpdate);
		ydata{n} = runningMin(info(:,1));
		xdata{n} = cumsum(info(:,2));
		if min(info(:,1)) < minY
			minY = min(info(:,1));
		end
		legendStr{n} = method;
		colors(n,:) = methods{m,8};
		lineStyles{n} = methods{m,9};
		n = n + 1;
	end
	
	for n = 1:length(ydata)
		ydata{n} = ydata{n}-minY;
	end
	
	if plotResults
		options.legendStr = legendStr;
		options.colors = colors;
		options.lineStyles = lineStyles;
		options.logScale = 2;
		options.legendLoc = 'NorthEast';
        options.legendFontSize = 16;
		options.legendFontWeight = 'bold';
		options.fontSize = 14;
		figure;
		prettyPlot3(xdata,ydata,options);
		xlim([1 maxPlotIter]);
		yl = ylim;
		yl(1) = 1e-14;
		switch dataset				
			case '9_Tumors.mat'
				yl(1) = 1e-13;
			case 'Brain_Tumor1.mat'
				yl(1) = 1e-11;
			case 'SRBCT.mat'
				yl(1) = 1e-10;
			case 'Leukemia1.mat'
				yl(1) = 1e-13;
		end
		if yl(2) >= yl(1)
		ylim(yl);
		end
		set(gca,'xtick',[100 200 300 400 500])
		print('-dpdf',sprintf('figures/exp_%s_%d_%s.pdf',experiment,accelerate,dataset));
		%pause
	end
end
